@@ -2,7 +2,7 @@ from typing import List, Iterator
 
 from pyot.conf.model import models
 from pyot.core.functional import cache_indexes, lazy_property
-from pyot.utils.lol.cdragon import abs_url, sanitize
+from pyot.utils.lol.cdragon import abs_url, sanitize_description
 from .base import PyotCore
 
 
@@ -36,7 +36,7 @@ class Rune(PyotCore):
 
     @lazy_property
     def cleaned_description(self) -> str:
-        return sanitize(self.long_description)
+        return sanitize_description(self.long_description)
 
 
 class Runes(PyotCore):
