@@ -75,7 +75,7 @@ class Summoner(PyotCore):
     @property
     def account(self) -> "Account":
         from ..riot.account import Account
-        return Account(puuid=self.puuid).pipeline(self.metapipeline.name)
+        return Account(puuid=self.puuid).using(self.metapipeline.name)
 
     @property
     def match_history(self) -> "MatchHistory":
