@@ -1,6 +1,5 @@
 from typing import List, Iterator, TYPE_CHECKING
 
-from pyot.core.functional import parse_camelcase
 from .base import PyotCore, PyotStatic
 
 if TYPE_CHECKING:
@@ -28,15 +27,11 @@ class TournamentProvider(PyotCore):
         self.initialize(locals())
 
     def body(self, region: str, url: str):
-        '''Body parameters setter.'''
-        if not url.startswith("https://") and not url.startswith("http://"):
-            raise TypeError("url should be well-formed, starting with an http protocol")
-        if region not in {"BR", "EUNE", "EUW", "JP", "LAN", "LAS", "NA", "OCE", "PBE", "RU", "TR"}:
-            raise TypeError(f"Invalid region '{region}' parameter, region in tournament-v4 uses client keys (NA, EUW, BR, LAN, ...)")
-        self._meta.body = parse_camelcase(locals())
+        '''Set body request parameters.'''
+        super()._place_body(locals())
         return self
 
-    def clean(self):
+    def validate(self):
         if not hasattr(self._meta, "body"):
             raise TypeError("This object's body parameters is required")
 
@@ -61,13 +56,11 @@ class Tournament(PyotCore):
         self.initialize(locals())
 
     def body(self, name: str, provider_id: int):
-        '''Body parameters setter.'''
-        if not isinstance(provider_id, int):
-            raise TypeError("provider_id must be int type")
-        self._meta.body = parse_camelcase(locals())
+        '''Set body request parameters.'''
+        super()._place_body(locals())
         return self
 
-    def clean(self):
+    def validate(self):
         if not hasattr(self._meta, "body"):
             raise TypeError("This object's body parameters is required")
 
@@ -136,14 +129,8 @@ class TournamentCode(PyotCore):
         self.initialize(locals())
 
     def body(self, map_type: str, pick_type: str, spectator_type: str, allowed_summoner_ids: List[str] = None):
-        '''Body parameters setter.'''
-        if pick_type not in ["BLIND_PICK", "DRAFT_MODE", "ALL_RANDOM", "TOURNAMENT_DRAFT"]:
-            raise TypeError(f"Invalid pick type '{pick_type}' parameter, must be one of BLIND_PICK, DRAFT_MODE, ALL_RANDOM, TOURNAMENT_DRAFT")
-        if map_type not in ["SUMMONERS_RIFT", "TWISTED_TREELINE", "HOWLING_ABYSS"]:
-            raise TypeError(f"Invalid map type '{map_type}' parameter, must be one of SUMMONERS_RIFT, TWISTED_TREELINE, HOWLING_ABYSS")
-        if spectator_type not in ["NONE", "LOBBYONLY", "ALL"]:
-            raise TypeError(f"Invalid spectator type '{spectator_type}' parameter, must be one of NONE, LOBBYONLY, ALL")
-        self._meta.body = parse_camelcase(locals())
+        '''Set body request parameters.'''
+        super()._place_body(locals())
         return self
 
     @property
@@ -164,25 +151,16 @@ class TournamentCodes(PyotCore):
         self.initialize(locals())
 
     def query(self, tournament_id: int, count: int = None):
-        if not isinstance(count, int) or count > 1000 or count < 1:
-            raise TypeError(f"Invalid count '{count}' parameter, must be between 1-5")
-        self._meta.query = parse_camelcase(locals())
+        '''Set query request parameters.'''
+        super()._place_query(locals())
         return self
 
     def body(self, map_type: str, pick_type: str, team_size: int, spectator_type: str, allowed_summoner_ids: List[str] = None, metadata: str = None):
-        '''Body parameters setter.'''
-        if pick_type not in ["BLIND_PICK", "DRAFT_MODE", "ALL_RANDOM", "TOURNAMENT_DRAFT"]:
-            raise TypeError(f"Invalid pick type '{pick_type}' parameter, must be one of BLIND_PICK, DRAFT_MODE, ALL_RANDOM, TOURNAMENT_DRAFT")
-        if map_type not in ["SUMMONERS_RIFT", "TWISTED_TREELINE", "HOWLING_ABYSS"]:
-            raise TypeError(f"Invalid map type '{map_type}' parameter, must be one of SUMMONERS_RIFT, TWISTED_TREELINE, HOWLING_ABYSS")
-        if spectator_type not in ["NONE", "LOBBYONLY", "ALL"]:
-            raise TypeError(f"Invalid spectator type '{spectator_type}' parameter, must be one of NONE, LOBBYONLY, ALL")
-        if not isinstance(team_size, int) or team_size > 5 or team_size < 1:
-            raise TypeError(f"Invalid team size '{team_size}' parameter, must be between 1-5")
-        self._meta.body = parse_camelcase(locals())
+        '''Set body request parameters.'''
+        super()._place_body(locals())
         return self
 
-    def clean(self):
+    def validate(self):
         if not hasattr(self._meta, "body"):
             raise TypeError("This object's body parameters is required")
         if not hasattr(self._meta, "query"):
