@@ -1,7 +1,6 @@
 from typing import List, Iterator, NoReturn, TYPE_CHECKING
 
 from pyot.conf.model import models
-from pyot.core.functional import parse_camelcase
 from .base import PyotCore, PyotStatic
 
 if TYPE_CHECKING:
@@ -143,9 +142,8 @@ class DivisionLeague(SummonerLeague):
         self.initialize(locals())
 
     def query(self, page: int = None):
-        '''Query parameters setter.'''
-        if page == 0: raise AttributeError("Invalid 'page' attribute, it should be greater than 0")
-        self._meta.query = parse_camelcase(locals())
+        '''Set query request parameters.'''
+        super()._place_query(locals())
         return self
 
     @property
