@@ -1,7 +1,6 @@
 from typing import List, TYPE_CHECKING
 
 from pyot.conf.model import models
-from pyot.core.functional import parse_camelcase
 from .base import PyotCore, PyotStatic
 
 if TYPE_CHECKING:
@@ -105,6 +104,6 @@ class Content(PyotCore):
         self.initialize(locals())
 
     def query(self, locale: str = None):
-        '''Query parameters setter.'''
-        self._meta.query = parse_camelcase(locals())
+        '''Set query request parameters.'''
+        super()._place_query(locals())
         return self
